==
easycython
==

`easycython.py` is a script that will attempt to
automatically convert one or more `.pyx` files into
the corresponding compiled `.pyd|.so` binary modules
files. Example::

    $ python easycython.py myext.pyx

Why?
==

Because writing a `setup.py` each time is painful.
